List:Commits« Previous MessageNext Message »
From:kent Date:October 29 2007 7:12pm
Subject:bk commit into 5.1 tree (kent:1.2592) BUG#31405
View as plain text  
Below is the list of changes that have just been committed into a local
5.1 repository of kent. When kent does a push these changes will
be propagated to the main repository and, within 24 hours after the
push, to the public repository.
For information on how to access the public repository
see http://dev.mysql.com/doc/mysql/en/installing-source-tree.html

ChangeSet@stripped, 2007-10-29 20:12:44+01:00, kent@stripped +2 -0
  autorun.sh:
    Removed innobase from compile-dist, and let it use autorun.sh to avoid
    code duplication. Also corrected a problem when searching for one of
    "libtoolize" and "glibtoolize", now it honors the PATH setting (Bug#31405)

  BUILD/autorun.sh@stripped, 2007-10-29 20:10:53+01:00, kent@stripped +16 -7
    Removed innobase from compile-dist, and let it use autorun.sh to avoid
    code duplication. Also corrected a problem when searching for one of
    "libtoolize" and "glibtoolize", now it honors the PATH setting (Bug#31405)

  BUILD/compile-dist@stripped, 2007-10-29 20:12:28+01:00, kent@stripped +3 -8

diff -Nrup a/BUILD/compile-dist b/BUILD/compile-dist
--- a/BUILD/compile-dist	2007-08-31 01:17:26 +02:00
+++ b/BUILD/compile-dist	2007-10-29 20:12:28 +01:00
@@ -7,14 +7,9 @@
 # package" that is used as the basis for all other binary builds.
 #
 test -f Makefile && make maintainer-clean
-(cd storage/innobase && aclocal && autoheader && \
-    libtoolize --automake --force --copy && \
-    automake --force --add-missing --copy && autoconf)
-aclocal
-autoheader
-libtoolize --automake --force --copy
-automake --force --add-missing --copy
-autoconf
+
+path=`dirname $0`
+. $path/autorun.sh
 
 # Default to gcc for CC and CXX
 if test -z "$CXX" ; then
Thread
bk commit into 5.1 tree (kent:1.2592) BUG#31405kent29 Oct
Re: bk commit into 5.1 tree (kent:1.2592) BUG#31405Kent Boortz29 Oct
diff -Nrup a/BUILD/autorun.sh b/BUILD/autorun.sh
--- a/BUILD/autorun.sh	2006-08-23 22:59:13 +02:00
+++ b/BUILD/autorun.sh	2007-10-29 20:10:53 +01:00
@@ -3,20 +3,29 @@
 
 die() { echo "$@"; exit 1; }
 
-# Added glibtoolize reference to make native OSX autotools work
-if [ -f /usr/bin/glibtoolize ]
+# Added glibtoolize reference to make native OSX autotools work,
+# we pick the first of glibtoolize/libtoolize we find in PATH
+LIBTOOLIZE=libtoolize  # Default
+IFS="${IFS=   }"; save_ifs="$IFS"; IFS=':'
+for dir in $PATH
+do
+  if test -f $dir/glibtoolize
   then
     LIBTOOLIZE=glibtoolize
-  else
-    LIBTOOLIZE=libtoolize
-fi
+    break
+  elif test -f $dir/libtoolize
+  then
+    break
+  fi
+done
+IFS="$save_ifs"
 
 aclocal || die "Can't execute aclocal" 
 autoheader || die "Can't execute autoheader"
 # --force means overwrite ltmain.sh script if it already exists 
-$LIBTOOLIZE --automake --force || die "Can't execute libtoolize"
+$LIBTOOLIZE --automake --force --copy || die "Can't execute libtoolize"
   
 # --add-missing instructs automake to install missing auxiliary files
 # and --force to overwrite them if they already exist
-automake --add-missing --force || die "Can't execute automake"
+automake --add-missing --force  --copy || die "Can't execute automake"
 autoconf || die "Can't execute autoconf"